summaryrefslogtreecommitdiff
path: root/src/picture_asset.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/picture_asset.h')
-rw-r--r--src/picture_asset.h14
1 files changed, 9 insertions, 5 deletions
diff --git a/src/picture_asset.h b/src/picture_asset.h
index e540c074..9fa4f99e 100644
--- a/src/picture_asset.h
+++ b/src/picture_asset.h
@@ -33,7 +33,8 @@ public:
/** Construct a PictureAsset, generating the MXF from the JPEG2000 files.
* This may take some time; progress is indicated by emission of the Progress signal.
* @param files Pathnames of JPEG2000 files, in frame order.
* @param mxf_path Pathname of MXF file to create.
* @param progress Signal to inform of progress.
* @param fps Frames per second.
* @param length Length in frames.
@@ -42,7 +43,8 @@ public:
*/
PictureAsset (
std::vector<std::string> const & files,
- std::string mxf_path,
+ std::string directory,
+ std::string mxf_name,
sigc::signal1<void, float>* progress,
int fps,
int length,
@@ -53,7 +55,8 @@ public:
/** Construct a PictureAsset, generating the MXF from the JPEG2000 files.
* This may take some time; progress is indicated by emission of the Progress signal.
* @param get_path Functor which returns a JPEG2000 file path for a given frame (frames counted from 0).
* @param mxf_path Pathname of MXF file to create.
* @param progress Signal to inform of progress.
* @param fps Frames per second.
* @param length Length in frames.
@@ -62,7 +65,8 @@ public:
*/
PictureAsset (
sigc::slot<std::string, int> get_path,
- std::string mxf_path,
+ std::string directory,
+ std::string mxf_name,
sigc::signal1<void, float>* progress,
int fps,
int length,
@@ -70,7 +74,7 @@ public:
int height
);
- PictureAsset (std::string mxf_path, int fps, int length, int width, int height);
+ PictureAsset (std::string directory, std::string mxf_name, int fps, int length, int width, int height);
/** Write details of this asset to a CPL stream.
* @param s Stream.
@@ -33,7 +33,8 @@ public:
* This may take some time; progress is indicated by emission of the Progress signal.
* @param files Pathnames of JPEG2000 files, in frame order.
- * @param mxf_path Pathname of MXF file to create.
+ * @param directory Directory in which to create MXF file.
+ * @param mxf_name Name of MXF file to create.
* @param progress Signal to inform of progress.
* @param fps Frames per second.
@@ -53,7 +55,8 @@ public:
* This may take some time; progress is indicated by emission of the Progress signal.
* @param get_path Functor which returns a JPEG2000 file path for a given frame (frames counted from 0).
- * @param mxf_path Pathname of MXF file to create.
+ * @param directory Directory in which to create MXF file.
+ * @param mxf_name Name of MXF file to create.
* @param progress Signal to inform of progress.
* @param fps Frames per second.